==> custom-toolbox_24.6.tar.xz: BUILD/translations/custom-toolbox_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>Özel Araç Kutusu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Başlatıcıyı özelleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Uygulamayı kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Bu özel bir başlatıcıdır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Bu pencereyi her açılışta göster</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>Liste Dosyasını Aç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>Liste Dosyaları (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>Dosya Açılırken Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>Dosya açılamadı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox, özel bir başlatıcı oluşturmak için kullanılan bir araçtır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Bu uygulama, özel başlatıcı oluşturmak için kullanılabilir: düğme/simge kutusu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>&quot;Bu iletişim kutusunu başlangıçta göster&quot; onay kutusunu gösterme</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Uygulamayı kurmak için yüklemek istediğiniz .list dosyasının tam yolu ve adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Görünüşe göre root olarak girmişsiniz, lütfen çıkın ve bu programı kullanmak için normal kullanıcı olarak girin. </translation>
    </message>
</context>
</TS>

==> custom-toolbox_25.2.tar.xz: BUILD/translations/custom-toolbox_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Custom Toolbox</source>
        <translation>Özel Araç Kutusu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Başlatıcıyı özelleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Uygulamayı kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Bu özel bir başlatıcıdır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Bu pencereyi her açılışta göster</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Execution Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>Failed to execute command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Failed to start program: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Open List File</source>
        <translation>Liste Dosyasını Aç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>List Files (*.list)</source>
        <translation>Liste Dosyaları (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>File Selection Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>No file selected. Application will now exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>File Open Error</source>
        <translation>Dosya Açılırken Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Could not open file: </source>
        <translation>Dosya açılamadı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox, özel bir başlatıcı oluşturmak için kullanılan bir araçtır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Could not write file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>File Removal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>Could not remove file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Bu uygulama, özel başlatıcı oluşturmak için kullanılabilir: düğme/simge kutusu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>&quot;Bu iletişim kutusunu başlangıçta göster&quot; onay kutusunu gösterme</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Uygulamayı kurmak için yüklemek istediğiniz .list dosyasının tam yolu ve adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Görünüşe göre root olarak girmişsiniz, lütfen çıkın ve bu programı kullanmak için normal kullanıcı olarak girin. </translation>
    </message>
</context>
</TS>
